@@ -1,27 +1,20 @@
-from __future__ import absolute_import, unicode_literals
+from unittest import skipUnless
 
-import sys
-
-if sys.version_info < (2, 7):
-    from unittest2 import skipUnless
-else:
-    from unittest import skipUnless
-
-from prometheus_client import Counter
-from prometheus_client import CollectorRegistry, generate_latest
+from prometheus_client import CollectorRegistry, Counter, generate_latest
 
 try:
+    from twisted.internet import reactor
+    from twisted.trial.unittest import TestCase
+    from twisted.web.client import Agent, readBody
+    from twisted.web.resource import Resource
+    from twisted.web.server import Site
+
     from prometheus_client.twisted import MetricsResource
 
-    from twisted.trial.unittest import TestCase
-    from twisted.web.server import Site
-    from twisted.web.resource import Resource
-    from twisted.internet import reactor
-    from twisted.web.client import Agent
-    from twisted.web.client import readBody
     HAVE_TWISTED = True
 except ImportError:
     from unittest import TestCase
+
     HAVE_TWISTED = False
 
 
@@ -44,7 +37,7 @@ class MetricsResourceTest(TestCase):
 
         agent = Agent(reactor)
         port = server.getHost().port
-        url = "http://localhost:{port}/metrics".format(port=port)
+        url = f"http://localhost:{port}/metrics"
         d = agent.request(b"GET", url.encode("ascii"))
 
         d.addCallback(readBody)
